"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createNodesV2 = exports.createNodes = exports.defaultOptions = exports.webDevServerCommand = exports.webDevServerConfigFileNameGlob = void 0;
const devkit_1 = require("@nx/devkit");
const node_fs_1 = require("node:fs");
const node_path_1 = require("node:path");
exports.webDevServerConfigFileNameGlob = '**/@(web-dev-server|wds).config.@(js|cjs|mjs)';
exports.webDevServerCommand = 'web-dev-server';
exports.defaultOptions = {
    targetName: 'serve',
};
exports.createNodes = [
    exports.webDevServerConfigFileNameGlob,
    (webDevServerConfigPath, options, context) => createWebDevServerTarget(webDevServerConfigPath, { ...exports.defaultOptions, ...options }, context),
];
exports.createNodesV2 = [
    exports.webDevServerConfigFileNameGlob,
    (webDevServerConfigPaths, options, context) => {
        return (0, devkit_1.createNodesFromFiles)(createWebDevServerTarget, webDevServerConfigPaths, { ...exports.defaultOptions, ...options }, context);
    },
];
/**
 * @param webDevServerConfigPath - Relative to `context.workspaceRoot` e.g
 *   `path/to/web-dev-server.config.js`
 * @param options
 * @param context
 * @returns
 */
const createWebDevServerTarget = (webDevServerConfigPath, options, context) => {
    const { targetName } = options;
    const webDevServerConfigDirectory = (0, node_path_1.dirname)(webDevServerConfigPath);
    if (!isNonRootProject(webDevServerConfigDirectory, context)) {
        return {};
    }
    return {
        projects: {
            [webDevServerConfigDirectory]: {
                targets: {
                    [targetName]: {
                        command: `${exports.webDevServerCommand} --config=${webDevServerConfigPath}`,
                    },
                },
            },
        },
    };
};
/**
 * @param directory - Relative to `context.workspaceRoot` e.g path/to/directory
 * @param context
 * @returns Whether the directory is considered a non root project.
 */
const isNonRootProject = (directory, context) => {
    if (directory === '.')
        return false;
    return ((0, node_fs_1.existsSync)((0, node_path_1.join)(context.workspaceRoot, directory, 'project.json')) ||
        (0, node_fs_1.existsSync)((0, node_path_1.join)(context.workspaceRoot, directory, 'package.json')));
};
//# sourceMappingURL=plugin.js.map